@@ -1,6 +1,7 @@
 """Spectral biclustering algorithms."""
-# Authors : Kemal Eren
-# License: BSD 3 clause
+
+# Authors: The scikit-learn developers
+# SPDX-License-Identifier: BSD-3-Clause
 
 from abc import ABCMeta, abstractmethod
 from numbers import Integral
@@ -14,7 +15,7 @@ from ..base import BaseEstimator, BiclusterMixin, _fit_context
 from ..utils import check_random_state, check_scalar
 from ..utils._param_validation import Interval, StrOptions
 from ..utils.extmath import make_nonnegative, randomized_svd, safe_sparse_dot
-from ..utils.validation import assert_all_finite
+from ..utils.validation import assert_all_finite, validate_data
 from ._kmeans import KMeans, MiniBatchKMeans
 
 __all__ = ["SpectralCoclustering", "SpectralBiclustering"]
@@ -130,7 +131,7 @@ class BaseSpectral(BiclusterMixin, BaseEstimator, metaclass=ABCMeta):
         self : object
             SpectralBiclustering instance.
         """
-        X = self._validate_data(X, accept_sparse="csr", dtype=np.float64)
+        X = validate_data(self, X, accept_sparse="csr", dtype=np.float64)
         self._check_parameters(X.shape[0])
         self._fit(X)
         return self
@@ -192,19 +193,6 @@ class BaseSpectral(BiclusterMixin, BaseEstimator, metaclass=ABCMeta):
         labels = model.labels_
         return centroid, labels
 
-    def _more_tags(self):
-        return {
-            "_xfail_checks": {
-                "check_estimators_dtypes": "raises nan error",
-                "check_fit2d_1sample": "_scale_normalize fails",
-                "check_fit2d_1feature": "raises apply_along_axis error",
-                "check_estimator_sparse_data": "does not fail gracefully",
-                "check_methods_subset_invariance": "empty array passed inside",
-                "check_dont_overwrite_parameters": "empty array passed inside",
-                "check_fit2d_predict1d": "empty array passed inside",
-            }
-        }
-
 
 class SpectralCoclustering(BaseSpectral):
     """Spectral Co-Clustering algorithm (Dhillon, 2001).
@@ -484,6 +472,9 @@ class SpectralBiclustering(BaseSpectral):
     array([1, 0], dtype=int32)
     >>> clustering
     SpectralBiclustering(n_clusters=2, random_state=0)
+
+    For a more detailed example, see
+    :ref:`sphx_glr_auto_examples_bicluster_plot_spectral_biclustering.py`
     """
 
     _parameter_constraints: dict = {
